@@ -1,9 +1,9 @@
 /* This file is auto generated, version 1 */
 /* SMP */
 #define UTS_MACHINE "x86_64"
-#define UTS_VERSION "#1 SMP Sun Apr 20 05:23:49 UTC 2008"
-#define LINUX_COMPILE_TIME "05:23:49"
-#define LINUX_COMPILE_BY "debuild"
+#define UTS_VERSION "#1 SMP Wed Oct 8 04:09:41 UTC 2008"
+#define LINUX_COMPILE_TIME "04:09:41"
+#define LINUX_COMPILE_BY "root"
 #define LINUX_COMPILE_HOST "debuild"
 #define LINUX_COMPILE_DOMAIN "mit.edu"
 #define LINUX_COMPILER "gcc version 4.1.2 20061115 (prerelease) (Debian 4.1.1-21)"
